@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for codeguru-reviewer service client
 
@@ -10,10 +11,11 @@ Usage::
     client: CodeGuruReviewerClient = boto3.client("codeguru-reviewer")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_codeguru_reviewer.paginator import ListRepositoryAssociationsPaginator
 from mypy_boto3_codeguru_reviewer.type_defs import (
     AssociateRepositoryResponseTypeDef,
@@ -157,7 +159,6 @@ class CodeGuruReviewerClient:
         [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
         """
 
-    @overload
     def get_paginator(
         self, operation_name: Literal["list_repository_associations"]
     ) -> ListRepositoryAssociationsPaginator:
